Handler

Trait Handler 

pub trait Handler:
    Send
    + Sync
    + 'static {
    // Required method
    fn handle<'life0, 'life1, 'async_trait>(
        &'life0 self,
        req: &'life1 mut Request,
    ) -> Pin<Box<dyn Future<Output = Result<Response>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}
Handlers are responsible for handling requests by creating Responses from those Requests.

Required Methods

fn handle<'life0, 'life1, 'async_trait>( &'life0 self, req: &'life1 mut Request, ) -> Pin<Box<dyn Future<Output = Result<Response>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Produce a Response from a Request, with the possibility of error.